# cmemc

cmemc is the official command line client for [eccenca Corporate Memory](https://documentation.eccenca.com/).

## Installation

In order to install the cmemc, run:

    pip install cmem-cmemc

You may consider installing cmemc only for the current user:

    pip install cmem-cmemc --user

## Configuration and Usage

cmemc is intended for System Administrators and Linked Data Expert, who wants to automate and remote control activities on eccenca Corporate Memory.

The cmemc manual including basic usage pattern, configuration as well as a command reference is available at:

[https://eccenca.com/go/cmemc](https://eccenca.com/go/cmemc)

cmemc only works with Python 3 and refuses to work with Python 2.x.
In addition to that, cmemc will warn you in case an untested Python environment is used.

